@@ -1,4 +1,4 @@
-use crate::io::Encode;
+use crate::io::ProtocolEncode;
 use crate::protocol::Capabilities;
 
 // https://dev.mysql.com/doc/internals/en/com-stmt-close.html
@@ -8,9 +8,10 @@ pub struct StmtClose {
     pub statement: u32,
 }
 
-impl Encode<'_, Capabilities> for StmtClose {
-    fn encode_with(&self, buf: &mut Vec<u8>, _: Capabilities) {
+impl ProtocolEncode<'_, Capabilities> for StmtClose {
+    fn encode_with(&self, buf: &mut Vec<u8>, _: Capabilities) -> Result<(), crate::Error> {
         buf.push(0x19); // COM_STMT_CLOSE
         buf.extend(&self.statement.to_le_bytes());
+        Ok(())
     }
 }
