@@ -46,6 +46,6 @@ impl ColumnIndex<MySqlRow> for &'_ str {
         row.column_names
             .get(*self)
             .ok_or_else(|| Error::ColumnNotFound((*self).into()))
-            .map(|v| *v)
+            .copied()
     }
 }
